#ifndef CTextInputData_included
#define CTextInputData_included

#include <qdialog.h>
#include <qlabel.h>
#include <qpushbutton.h>
#include <qlineedit.h>

class CTextInputData : public QDialog
{
    Q_OBJECT

public:

    CTextInputData
    (
        QWidget* parent = NULL,
        const char* name = NULL
    );

    virtual ~CTextInputData();

public slots:


protected slots:

    virtual void inputChanged(const QString&);
    virtual void accept_field();

protected:
    QLineEdit* InputField;
    QPushButton* OkButton;
    QLabel* InputLabel;

};

#endif // CTextInputData_included
